##  Managing Technical Users
Multiple administrators can collaboratively manage technical users. As an administrator, you can:
  * Create technical users
  * Replace the API token of a technical user: To do this, click Replace token on the technical user you need, then confirm your action. When you replace an API token, the previous token is disabled. Any integrations or scripts using the previous token will stop working.
  * Update a technical user: To update the details associated with a technical user, select a user on the Technical Users page, and update the information you need. You can change the expiration date of the associated API token, but this action doesn’t replace or delete the token.
  * View the changelog of associated actions: To view the history of updates for a technical user, click History on the technical user you need. You can see the full changelog of actions associated with the user.
  * Delete a technical user: To do this, click the trash bin icon on the technical user you need, then confirm your action. When you delete a technical user, the API token associated with the user is also deleted. Any integrations or scripts using the token will stop working.
